@@ -23,28 +23,28 @@ var searchData=
   ['scopedtrywritelock_20',['ScopedTryWriteLock',['../classScopedTryWriteLock.html',1,'']]],
   ['scopedvaluesetter_21',['ScopedValueSetter',['../classScopedValueSetter.html',1,'']]],
   ['scopedwritelock_22',['ScopedWriteLock',['../classScopedWriteLock.html',1,'']]],
-  ['scrollbar_23',['ScrollBar',['../classScrollBar.html',1,'']]],
-  ['selecteditemset_24',['SelectedItemSet',['../classSelectedItemSet.html',1,'']]],
-  ['service_25',['Service',['../structNetworkServiceDiscovery_1_1Service.html',1,'NetworkServiceDiscovery']]],
-  ['settabletooltipclient_26',['SettableTooltipClient',['../classSettableTooltipClient.html',1,'']]],
-  ['settings_27',['Settings',['../structPushNotifications_1_1Settings.html',1,'PushNotifications']]],
-  ['sha256_28',['SHA256',['../classSHA256.html',1,'']]],
-  ['shapebutton_29',['ShapeButton',['../classShapeButton.html',1,'']]],
-  ['sharedpointer_30',['SharedPointer',['../classWeakReference_1_1SharedPointer.html',1,'WeakReference']]],
-  ['sharedresourcepointer_31',['SharedResourcePointer',['../classSharedResourcePointer.html',1,'']]],
-  ['sharedresourcepointer_3c_20messagethread_20_3e_32',['SharedResourcePointer&lt; MessageThread &gt;',['../classSharedResourcePointer.html',1,'']]],
-  ['sidepanel_33',['SidePanel',['../classSidePanel.html',1,'']]],
-  ['simdregister_34',['SIMDRegister',['../structdsp_1_1SIMDRegister.html',1,'dsp']]],
-  ['singlethreadedabstractfifo_35',['SingleThreadedAbstractFifo',['../classSingleThreadedAbstractFifo.html',1,'']]],
-  ['singlethreadediirfilter_36',['SingleThreadedIIRFilter',['../classSingleThreadedIIRFilter.html',1,'']]],
-  ['singlethreadedreferencecountedobject_37',['SingleThreadedReferenceCountedObject',['../classSingleThreadedReferenceCountedObject.html',1,'']]],
-  ['singletonholder_38',['SingletonHolder',['../structSingletonHolder.html',1,'']]],
-  ['slider_39',['Slider',['../classSlider.html',1,'']]],
-  ['sliderattachment_40',['SliderAttachment',['../classAudioProcessorValueTreeState_1_1SliderAttachment.html',1,'AudioProcessorValueTreeState']]],
-  ['sliderlayout_41',['SliderLayout',['../structSlider_1_1SliderLayout.html',1,'Slider']]],
-  ['sliderparameterattachment_42',['SliderParameterAttachment',['../classSliderParameterAttachment.html',1,'']]],
-  ['sliderpropertycomponent_43',['SliderPropertyComponent',['../classSliderPropertyComponent.html',1,'']]],
-  ['smallestfloattype_44',['SmallestFloatType',['../structTypeHelpers_1_1SmallestFloatType.html',1,'TypeHelpers']]],
+  ['scopeguard_23',['ScopeGuard',['../structScopeGuard.html',1,'']]],
+  ['scrollbar_24',['ScrollBar',['../classScrollBar.html',1,'']]],
+  ['selecteditemset_25',['SelectedItemSet',['../classSelectedItemSet.html',1,'']]],
+  ['service_26',['Service',['../structNetworkServiceDiscovery_1_1Service.html',1,'NetworkServiceDiscovery']]],
+  ['settabletooltipclient_27',['SettableTooltipClient',['../classSettableTooltipClient.html',1,'']]],
+  ['settings_28',['Settings',['../structPushNotifications_1_1Settings.html',1,'PushNotifications']]],
+  ['sha256_29',['SHA256',['../classSHA256.html',1,'']]],
+  ['shapebutton_30',['ShapeButton',['../classShapeButton.html',1,'']]],
+  ['sharedpointer_31',['SharedPointer',['../classWeakReference_1_1SharedPointer.html',1,'WeakReference']]],
+  ['sharedresourcepointer_32',['SharedResourcePointer',['../classSharedResourcePointer.html',1,'']]],
+  ['sharedresourcepointer_3c_20messagethread_20_3e_33',['SharedResourcePointer&lt; MessageThread &gt;',['../classSharedResourcePointer.html',1,'']]],
+  ['sidepanel_34',['SidePanel',['../classSidePanel.html',1,'']]],
+  ['simdregister_35',['SIMDRegister',['../structdsp_1_1SIMDRegister.html',1,'dsp']]],
+  ['singlethreadedabstractfifo_36',['SingleThreadedAbstractFifo',['../classSingleThreadedAbstractFifo.html',1,'']]],
+  ['singlethreadediirfilter_37',['SingleThreadedIIRFilter',['../classSingleThreadedIIRFilter.html',1,'']]],
+  ['singlethreadedreferencecountedobject_38',['SingleThreadedReferenceCountedObject',['../classSingleThreadedReferenceCountedObject.html',1,'']]],
+  ['singletonholder_39',['SingletonHolder',['../structSingletonHolder.html',1,'']]],
+  ['slider_40',['Slider',['../classSlider.html',1,'']]],
+  ['sliderattachment_41',['SliderAttachment',['../classAudioProcessorValueTreeState_1_1SliderAttachment.html',1,'AudioProcessorValueTreeState']]],
+  ['sliderlayout_42',['SliderLayout',['../structSlider_1_1SliderLayout.html',1,'Slider']]],
+  ['sliderparameterattachment_43',['SliderParameterAttachment',['../classSliderParameterAttachment.html',1,'']]],
+  ['sliderpropertycomponent_44',['SliderPropertyComponent',['../classSliderPropertyComponent.html',1,'']]],
   ['smoothedvalue_45',['SmoothedValue',['../classSmoothedValue.html',1,'']]],
   ['smoothedvalue_3c_20float_20_3e_46',['SmoothedValue&lt; float &gt;',['../classSmoothedValue.html',1,'']]],
   ['smoothedvalue_3c_20numerictype_20_3e_47',['SmoothedValue&lt; NumericType &gt;',['../classSmoothedValue.html',1,'']]],
@@ -64,7 +64,7 @@ var searchData=
   ['sortedset_3c_20value_20_2a_20_3e_61',['SortedSet&lt; Value * &gt;',['../classSortedSet.html',1,'']]],
   ['soundplayer_62',['SoundPlayer',['../classSoundPlayer.html',1,'']]],
   ['sourcedetails_63',['SourceDetails',['../classDragAndDropTarget_1_1SourceDetails.html',1,'DragAndDropTarget']]],
-  ['span_64',['Span',['../structGridItem_1_1Span.html',1,'GridItem']]],
+  ['span_64',['Span',['../structAccessibilityTableInterface_1_1Span.html',1,'AccessibilityTableInterface::Span'],['../structGridItem_1_1Span.html',1,'GridItem::Span']]],
   ['sparseset_65',['SparseSet',['../classSparseSet.html',1,'']]],
   ['sparseset_3c_20int_20_3e_66',['SparseSet&lt; int &gt;',['../classSparseSet.html',1,'']]],
   ['speakermappings_67',['SpeakerMappings',['../structSpeakerMappings.html',1,'']]],
