@@ -15,6 +15,6 @@ var searchData=
   ['storageformat_12',['StorageFormat',['../classPropertiesFile.html#ac4d1ac9a6b624f7e0de7787de46dc05e',1,'PropertiesFile']]],
   ['streamflags_13',['StreamFlags',['../classChildProcess.html#a9e7be158550b4d2a470e4cceef501892',1,'ChildProcess']]],
   ['streamkind_14',['StreamKind',['../classCoreAudioFormat.html#a892e81f36a7ca376a0a83cfba0351e2f',1,'CoreAudioFormat']]],
-  ['style_15',['Style',['../classComponentPeer.html#af3f12e11d020aae24801145f0238e8ac',1,'ComponentPeer::Style()'],['../structPushNotifications_1_1Notification_1_1Action.html#a8694375bdc3dd690cb12a97cab9570c0',1,'PushNotifications::Notification::Action::Style()']]],
+  ['style_15',['Style',['../classComponentPeer.html#af3f12e11d020aae24801145f0238e8ac',1,'ComponentPeer::Style'],['../structPushNotifications_1_1Notification_1_1Action.html#a8694375bdc3dd690cb12a97cab9570c0',1,'PushNotifications::Notification::Action::Style']]],
   ['styleflags_16',['StyleFlags',['../classComponentPeer.html#a94a21f91c61f8211774d6f43243a6ddc',1,'ComponentPeer']]]
 ];
