@@ -3,10 +3,10 @@ var searchData=
   ['filechooserflags_0',['FileChooserFlags',['../classFileBrowserComponent.html#a32888a950cc0e51c8e1350f53bea43d6',1,'FileBrowserComponent']]],
   ['filtertype_1',['FilterType',['../classdsp_1_1Oversampling.html#ac3d048707b7807badec0df770c9778f8',1,'dsp::Oversampling']]],
   ['firstordertptfiltertype_2',['FirstOrderTPTFilterType',['../namespacedsp.html#ae95dedb418a8687b6f966f9dc92a4603',1,'dsp']]],
-  ['flags_3',['Flags',['../classJustification.html#a1f8c07756c56fe8f31ed44964e51bfbc',1,'Justification::Flags()'],['../classRectanglePlacement.html#afd5464553fd6bb41d697f3fc1d7427ed',1,'RectanglePlacement::Flags()'],['../classModifierKeys.html#acdd2a85defa6a705d74e1a63d193678b',1,'ModifierKeys::Flags()']]],
+  ['flags_3',['Flags',['../classJustification.html#a1f8c07756c56fe8f31ed44964e51bfbc',1,'Justification::Flags'],['../classRectanglePlacement.html#afd5464553fd6bb41d697f3fc1d7427ed',1,'RectanglePlacement::Flags'],['../classModifierKeys.html#acdd2a85defa6a705d74e1a63d193678b',1,'ModifierKeys::Flags']]],
   ['focuschangetype_4',['FocusChangeType',['../classComponent.html#a7fd775ea6b1190d5d694fdffa539dfac',1,'Component']]],
   ['focuscontainertype_5',['FocusContainerType',['../classComponent.html#af4b602b33a2f82e39560fcffb6a2bd9e',1,'Component']]],
-  ['followsymlinks_6',['FollowSymlinks',['../classZipFile.html#a16ad335c8def5a80206070a64a42685e',1,'ZipFile']]],
+  ['followsymlinks_6',['FollowSymlinks',['../classFile.html#a0a1de7b7cf65e7502cac315b3d180aec',1,'File::FollowSymlinks'],['../classZipFile.html#a16ad335c8def5a80206070a64a42685e',1,'ZipFile::FollowSymlinks']]],
   ['fontstyleflags_7',['FontStyleFlags',['../classFont.html#a52a35b5dc1e6f782e25283c9283bae4f',1,'Font']]],
   ['format_8',['Format',['../classGZIPDecompressorInputStream.html#a293d005b03d528a89ec13cfb07e31f94',1,'GZIPDecompressorInputStream']]],
   ['frameratetype_9',['FrameRateType',['../classAudioPlayHead.html#a9afad1749c8002945b2a6921eef92b25',1,'AudioPlayHead']]]
