@@ -1,6 +1,6 @@
 var searchData=
 [
   ['fircoefficientsptr_0',['FIRCoefficientsPtr',['../structdsp_1_1FilterDesign.html#ac2ec41da614cadb901480dc30690aa79',1,'dsp::FilterDesign']]],
-  ['floattype_1',['FloatType',['../classSmoothedValueBase.html#a331eba8c0333698d8bb470b1311d49e4',1,'SmoothedValueBase::FloatType()'],['../classPoint.html#a615b0a2ff1a541e0ba8640d3ee6abaa7',1,'Point::FloatType()']]],
+  ['floattype_1',['FloatType',['../classSmoothedValueBase.html#a331eba8c0333698d8bb470b1311d49e4',1,'SmoothedValueBase::FloatType'],['../classPoint.html#a13f4d01778a86ac3f278984915546395',1,'Point::FloatType']]],
   ['formaterrorhandler_2',['FormatErrorHandler',['../classOSCReceiver.html#a7a3e4ed2e9aea01a1521e2b0aa9ceed2',1,'OSCReceiver']]]
 ];
