@@ -8,12 +8,12 @@ var searchData=
   ['salmon_5',['salmon',['../namespaceColours.html#a5d926bfb763818a5f64344a09b612ed1',1,'Colours']]],
   ['sampleposition_6',['samplePosition',['../structMidiMessageMetadata.html#a29f3e866c6b86f0f0947f81ecf390b57',1,'MidiMessageMetadata']]],
   ['sampler_7',['sampler',['../namespacegl.html#a256f905157e9c5e288e0523b9bdf2222',1,'gl']]],
-  ['samplerate_8',['sampleRate',['../structdsp_1_1ProcessSpec.html#a6c7c39e922722be2518a973f76a48fa6',1,'dsp::ProcessSpec::sampleRate()'],['../classAudioFormatWriter.html#aafefbda90e2a58cb057e89e995decfd2',1,'AudioFormatWriter::sampleRate()'],['../classAudioFormatReader.html#aafcd07b3ac08e83c019621cd8cd0c7c5',1,'AudioFormatReader::sampleRate()'],['../structAudioDeviceManager_1_1AudioDeviceSetup.html#afa56530d7a661131d8891f7b9874fcd1',1,'AudioDeviceManager::AudioDeviceSetup::sampleRate()']]],
+  ['samplerate_8',['sampleRate',['../structdsp_1_1ProcessSpec.html#a6c7c39e922722be2518a973f76a48fa6',1,'dsp::ProcessSpec::sampleRate'],['../classAudioFormatWriter.html#aafefbda90e2a58cb057e89e995decfd2',1,'AudioFormatWriter::sampleRate'],['../classAudioFormatReader.html#aafcd07b3ac08e83c019621cd8cd0c7c5',1,'AudioFormatReader::sampleRate'],['../structAudioDeviceManager_1_1AudioDeviceSetup.html#afa56530d7a661131d8891f7b9874fcd1',1,'AudioDeviceManager::AudioDeviceSetup::sampleRate']]],
   ['samplers_9',['samplers',['../namespacegl.html#a3ce0947680c05ffd906d53098f9d29b8',1,'gl']]],
   ['samples_10',['samples',['../namespacegl.html#a86d4caaead9cc2b5ad0ad5e23ae0568d',1,'gl']]],
   ['sandybrown_11',['sandybrown',['../namespaceColours.html#aca7d5a81d72547917b11b3476a201653',1,'Colours']]],
   ['scalar_12',['scalar',['../classQuaternion.html#adfe519277223a4cb9321dc7f0d3b5cca',1,'Quaternion']]],
-  ['scale_13',['scale',['../namespacegl.html#a4f27436ebaceab481939dc1f71b047dc',1,'gl::scale()'],['../structDisplays_1_1Display.html#a611a3fe584fa04e86538866af0e5d788',1,'Displays::Display::scale()']]],
+  ['scale_13',['scale',['../namespacegl.html#a4f27436ebaceab481939dc1f71b047dc',1,'gl::scale'],['../structDisplays_1_1Display.html#a611a3fe584fa04e86538866af0e5d788',1,'Displays::Display::scale']]],
   ['scalefactor_14',['scaleFactor',['../namespacegl.html#a089af03aaf065f0071f68976412d5fcc',1,'gl']]],
   ['scalefactorlisteners_15',['scaleFactorListeners',['../classComponentPeer.html#a3c815b759167f87c6c9aead83b737b3f',1,'ComponentPeer']]],
   ['scopeuid_16',['scopeUID',['../structExpression_1_1Symbol.html#aaddddb4fd2bad7fcce78adce69ba91d8',1,'Expression::Symbol']]],
@@ -48,7 +48,7 @@ var searchData=
   ['simdnumelements_45',['SIMDNumElements',['../structdsp_1_1SIMDRegister.html#a3a9f728b56ef1b9fd3fceddb51259918',1,'dsp::SIMDRegister']]],
   ['simdregistersize_46',['SIMDRegisterSize',['../structdsp_1_1SIMDRegister.html#a295428a84f540c2442e2c476abc49800',1,'dsp::SIMDRegister']]],
   ['sink_47',['sink',['../namespacegl.html#adf64419877a3a14f2ce4793a8d4e919d',1,'gl']]],
-  ['size_48',['size',['../classImage_1_1BitmapData.html#a60d26c041c2e0269be4ae728a527ea75',1,'Image::BitmapData::size()'],['../namespacegl.html#a441d79156826d7dfbf89100bb934a38d',1,'gl::size()']]],
+  ['size_48',['size',['../classImage_1_1BitmapData.html#a60d26c041c2e0269be4ae728a527ea75',1,'Image::BitmapData::size'],['../namespacegl.html#a441d79156826d7dfbf89100bb934a38d',1,'gl::size']]],
   ['size4d_49',['size4d',['../namespacegl.html#a99ec9e69e3ca31393906e681e379b02d',1,'gl']]],
   ['sizes_50',['sizes',['../namespacegl.html#a53714ae87440f8b11d33209e7093ace3',1,'gl']]],
   ['skew_51',['skew',['../classNormalisableRange.html#a740639acf2157636fce16138a51bbfa3',1,'NormalisableRange']]],
@@ -59,8 +59,8 @@ var searchData=
   ['sliderbounds_56',['sliderBounds',['../structSlider_1_1SliderLayout.html#a40ee690d7af050cd1d59b75142234817',1,'Slider::SliderLayout']]],
   ['snow_57',['snow',['../namespaceColours.html#a5f8c43c69872971f4bddb68a780dd2bf',1,'Colours']]],
   ['sounds_58',['sounds',['../classSynthesiser.html#ac64f99f204a1d5a567422cd9d5217081',1,'Synthesiser']]],
-  ['soundtoplay_59',['soundToPlay',['../structPushNotifications_1_1Notification.html#a3bc57c2d4c760a1eeefd90fa05bcd207',1,'PushNotifications::Notification::soundToPlay()'],['../structPushNotifications_1_1Channel.html#aa159faa73985e53ee97979ba56d9b767',1,'PushNotifications::Channel::soundToPlay()']]],
-  ['source_60',['source',['../classMouseEvent.html#a4f70eb92a29dc0acfa9f782388e254bc',1,'MouseEvent::source()'],['../structAudioProcessorGraph_1_1Connection.html#a05813b379dcc6ac0431f4492e6bb3b31',1,'AudioProcessorGraph::Connection::source()'],['../namespacegl.html#a3abd4558223a005891c686e9d22383df',1,'gl::source()']]],
+  ['soundtoplay_59',['soundToPlay',['../structPushNotifications_1_1Notification.html#a3bc57c2d4c760a1eeefd90fa05bcd207',1,'PushNotifications::Notification::soundToPlay'],['../structPushNotifications_1_1Channel.html#aa159faa73985e53ee97979ba56d9b767',1,'PushNotifications::Channel::soundToPlay']]],
+  ['source_60',['source',['../structAudioProcessorGraph_1_1Connection.html#a05813b379dcc6ac0431f4492e6bb3b31',1,'AudioProcessorGraph::Connection::source'],['../classMouseEvent.html#a4f70eb92a29dc0acfa9f782388e254bc',1,'MouseEvent::source'],['../namespacegl.html#a3abd4558223a005891c686e9d22383df',1,'gl::source']]],
   ['sourcebaselevel_61',['sourceBaseLevel',['../namespacegl.html#adc90d5ff1ef4db142546111cdcf1f38b',1,'gl']]],
   ['sourcecomponent_62',['sourceComponent',['../classDragAndDropTarget_1_1SourceDetails.html#ad64cf556308af58fb6873d16f4a590de',1,'DragAndDropTarget::SourceDetails']]],
   ['sourcelevelcount_63',['sourceLevelCount',['../namespacegl.html#a80d9dfd37086c3ecc9eac854d7ababeb',1,'gl']]],
@@ -92,55 +92,56 @@ var searchData=
   ['srcz_89',['srcZ',['../namespacegl.html#aad49d6c3912cc5dc18bc65061d054595',1,'gl']]],
   ['srxy_90',['srxY',['../namespacegl.html#a0a3051294b1d405cc3ae77a91225386c',1,'gl']]],
   ['stages_91',['stages',['../namespacegl.html#a506f6ab080db784dad27cb9d573a05ec',1,'gl']]],
-  ['start_92',['start',['../structGridItem_1_1StartAndEndProperty.html#a1f4e27e7a91ec09563b7655a3b4f5ccf',1,'GridItem::StartAndEndProperty::start()'],['../classNormalisableRange.html#adc186176e94c6f80eb2c626384054fe3',1,'NormalisableRange::start()'],['../structTextDiff_1_1Change.html#ac72e9e25d35530fac7837a2d22c31958',1,'TextDiff::Change::start()'],['../namespacegl.html#adad3a3824fbe72fb0b01074bb01ebe75',1,'gl::start()']]],
+  ['start_92',['start',['../structGridItem_1_1StartAndEndProperty.html#a1f4e27e7a91ec09563b7655a3b4f5ccf',1,'GridItem::StartAndEndProperty::start'],['../structTextDiff_1_1Change.html#ac72e9e25d35530fac7837a2d22c31958',1,'TextDiff::Change::start'],['../classNormalisableRange.html#adc186176e94c6f80eb2c626384054fe3',1,'NormalisableRange::start'],['../namespacegl.html#adad3a3824fbe72fb0b01074bb01ebe75',1,'gl::start']]],
   ['startangleradians_93',['startAngleRadians',['../structSlider_1_1RotaryParameters.html#a1b4090a3f77b0183b1c847525f4edb8a',1,'Slider::RotaryParameters']]],
   ['startindex1_94',['startIndex1',['../classAbstractFifo_1_1ScopedReadWrite.html#a102cfbf1cfd342be976af1e97b9ade27',1,'AbstractFifo::ScopedReadWrite']]],
   ['startindex2_95',['startIndex2',['../classAbstractFifo_1_1ScopedReadWrite.html#a742bae60eed284787472c86809f3b179',1,'AbstractFifo::ScopedReadWrite']]],
-  ['startpos_96',['startPos',['../classRelativePointPath_1_1StartSubPath.html#afcaa4975b6ef2fcc78e99b873a38d2d2',1,'RelativePointPath::StartSubPath']]],
-  ['startsample_97',['startSample',['../structAudioSourceChannelInfo.html#a42e88ccc05d4893015e2415785390259',1,'AudioSourceChannelInfo']]],
-  ['startsegment_98',['startSegment',['../namespacegl.html#af89e8b4413c870557c97cf9c8a3fe1e9',1,'gl']]],
-  ['starttime_99',['startTime',['../structUnitTestRunner_1_1TestResult.html#a4a9729ea0d39217a16dd619db024a398',1,'UnitTestRunner::TestResult']]],
-  ['state_100',['state',['../classAudioProcessorValueTreeState.html#ad7de02052d045956f56018e009dc50c6',1,'AudioProcessorValueTreeState::state()'],['../structdsp_1_1ProcessorDuplicator.html#a5907f78806648c78d794e1f16943df9d',1,'dsp::ProcessorDuplicator::state()'],['../classComponentBuilder.html#af09fdfb8bb0edf0a6c2f19d5d54563f4',1,'ComponentBuilder::state()']]],
-  ['statefilechooser_101',['stateFileChooser',['../classStandalonePluginHolder.html#a5f6cf68a9218c9f93837bc13b7841393',1,'StandalonePluginHolder']]],
-  ['states_102',['states',['../namespacegl.html#a1d1dfbaa95ddc71b55b20bca67a16d33',1,'gl']]],
-  ['statestack_103',['stateStack',['../classLowLevelGraphicsPostScriptRenderer.html#a95a55fd1cd7588048a37ac86fa384849',1,'LowLevelGraphicsPostScriptRenderer']]],
-  ['steelblue_104',['steelblue',['../namespaceColours.html#a588c5015b8beea03960fd220c973e70d',1,'Colours']]],
-  ['stencil_105',['stencil',['../namespacegl.html#a1c2ec637bc0712e4237c1b8c90e02322',1,'gl']]],
-  ['stencilbufferbits_106',['stencilBufferBits',['../classOpenGLPixelFormat.html#aa94f3f667e41465ea29b6f259d9abf8b',1,'OpenGLPixelFormat']]],
-  ['stencilcleartag_107',['stencilClearTag',['../namespacegl.html#a52d45314d431f7d64d9b7b64ef927f4e',1,'gl']]],
-  ['stopatend_108',['stopAtEnd',['../structSlider_1_1RotaryParameters.html#a2e705ed5eb148f3f3eb1e89a72ff634f',1,'Slider::RotaryParameters']]],
-  ['stopkey_109',['stopKey',['../classKeyPress.html#a4ebc694e95335f25418c99eb2235d815',1,'KeyPress']]],
-  ['storageblockbinding_110',['storageBlockBinding',['../namespacegl.html#ae1ba5ea319c913ae64e99bc0079ce5ab',1,'gl']]],
-  ['storageblockindex_111',['storageBlockIndex',['../namespacegl.html#a7f9b76ebc66e5542f5d192f0f01ec93c',1,'gl']]],
-  ['storageformat_112',['storageFormat',['../structPropertiesFile_1_1Options.html#aed68b3ff89a6943aeac93af26effec2d',1,'PropertiesFile::Options']]],
-  ['storagesamples_113',['storageSamples',['../namespacegl.html#a07bcb6b2ce71d0852a757daf63b263e6',1,'gl']]],
-  ['storagetype_114',['storagetype',['../namespacegl.html#a8938ecd8908fc581f46f9e6fd2079d2a',1,'gl']]],
-  ['stream_115',['stream',['../namespacegl.html#a3a0f500782e4461d09f1e29189835b3d',1,'gl']]],
-  ['stride_116',['stride',['../namespacegl.html#a5f655ae61ce43b078cbff7cfe363d568',1,'gl']]],
-  ['strides_117',['strides',['../namespacegl.html#ab3fb3e346bf30cc218822c55a0eb74c5',1,'gl']]],
-  ['string_118',['string',['../classOSCTypes.html#ad427b15ae32b26b2e0c28f0932eed263',1,'OSCTypes::string()'],['../namespacegl.html#ad7acdf57d94829f964ff1dc581fc4705',1,'gl::string()']]],
-  ['stringlen_119',['stringlen',['../namespacegl.html#acde29865e531b4849f88ed20c6dcf0a7',1,'gl']]],
-  ['stringrange_120',['stringRange',['../classTextLayout_1_1Run.html#a5e78255b382519784f9950efeae14f57',1,'TextLayout::Run::stringRange()'],['../classTextLayout_1_1Line.html#a2980388305522b3a4595196e7bbf09a2',1,'TextLayout::Line::stringRange()']]],
-  ['strings_121',['strings',['../namespacegl.html#a8639a2c90be16742b8efb795d7c7a4ed',1,'gl::strings()'],['../classStringArray.html#ac10f010a31e1dcd6220d278a1603e37a',1,'StringArray::strings()']]],
-  ['strokepath_122',['strokePath',['../classDrawableShape.html#a9400e1628d38b4719c211da4158bc2ff',1,'DrawableShape']]],
-  ['stroketype_123',['strokeType',['../classDrawableShape.html#af636e2ff4b818d2b51994291facb30f6',1,'DrawableShape']]],
-  ['style_124',['style',['../classTypeface.html#a4169174330e29936cda2170a51a36df8',1,'Typeface::style()'],['../classComponentPeer.html#aa96d0558fabd66eea5baeded157a873d',1,'ComponentPeer::style()'],['../structPushNotifications_1_1Notification_1_1Action.html#a3ae288a9d4a6c29d907430ee38229166',1,'PushNotifications::Notification::Action::style()']]],
-  ['styleflags_125',['styleFlags',['../classComponentPeer.html#a8322b7cdb134bc52f443cd587ffc3f75',1,'ComponentPeer']]],
-  ['subcategoryname_126',['subcategoryName',['../structUnitTestRunner_1_1TestResult.html#af0a632786980a63693a86bb9942959c0',1,'UnitTestRunner::TestResult']]],
-  ['subfolders_127',['subFolders',['../structKnownPluginList_1_1PluginTree.html#a46a202981e3ec6943e51ddbe2866a8d0',1,'KnownPluginList::PluginTree']]],
-  ['submenu_128',['subMenu',['../structPopupMenu_1_1Item.html#ac3da3a6179a8ddb32c3f8de05a4f91e1',1,'PopupMenu::Item']]],
-  ['subpathindex_129',['subPathIndex',['../classPathFlatteningIterator.html#a96ac386608cfe18dde7de5a433aac417',1,'PathFlatteningIterator']]],
-  ['subtitle_130',['subtitle',['../structPushNotifications_1_1Notification.html#a187733b87ad3bba14b690f021ac4ee0a',1,'PushNotifications::Notification']]],
-  ['succeeded_131',['succeeded',['../structOnlineUnlockStatus_1_1UnlockResult.html#a05958e80831364da7c4a2bead72fad6a',1,'OnlineUnlockStatus::UnlockResult']]],
-  ['suggestedcolour_132',['suggestedColour',['../structAudioProcessorEditor_1_1ParameterControlHighlightInfo.html#ae06159d036b60b93709ac4a5553af0ba',1,'AudioProcessorEditor::ParameterControlHighlightInfo']]],
-  ['sumoutput_133',['sumOutput',['../namespacegl.html#a5d14e91166b44ea9f8ebb94bd6c1a37b',1,'gl']]],
-  ['surfaces_134',['surfaces',['../namespacegl.html#a8c2d49638382f782b88bad56c901ccc7',1,'gl']]],
-  ['sustain_135',['sustain',['../structADSR_1_1Parameters.html#a3722c4a821ccb7affd869fb257729aa8',1,'ADSR::Parameters']]],
-  ['swizzle_136',['swizzle',['../namespacegl.html#a0f0f61c545262318ed8612d9b0186c8e',1,'gl']]],
-  ['swizzlew_137',['swizzlew',['../namespacegl.html#aaf72861e2d272a042d6645b0295c9cba',1,'gl']]],
-  ['swizzlex_138',['swizzlex',['../namespacegl.html#ab07ede14e70de55b831e8066e1d6c119',1,'gl']]],
-  ['swizzley_139',['swizzley',['../namespacegl.html#aaf990616a9884a909b1dc64f9011ec3e',1,'gl']]],
-  ['swizzlez_140',['swizzlez',['../namespacegl.html#a1c3cb1caa0d412fca8ecf375d5cf8351',1,'gl']]],
-  ['symbolname_141',['symbolName',['../structExpression_1_1Symbol.html#a8ea461b91478b99e10a04956c38f5d68',1,'Expression::Symbol']]],
-  ['symmetricskew_142',['symmetricSkew',['../classNormalisableRange.html#a3a588ad45b07463d74aca98d0589845d',1,'NormalisableRange']]]
+  ['startinsamples_96',['startInSamples',['../classARAPlaybackRegionReader.html#a87c8218dcb5c6aea12d5140013bfa68b',1,'ARAPlaybackRegionReader']]],
+  ['startpos_97',['startPos',['../classRelativePointPath_1_1StartSubPath.html#afcaa4975b6ef2fcc78e99b873a38d2d2',1,'RelativePointPath::StartSubPath']]],
+  ['startsample_98',['startSample',['../structAudioSourceChannelInfo.html#a42e88ccc05d4893015e2415785390259',1,'AudioSourceChannelInfo']]],
+  ['startsegment_99',['startSegment',['../namespacegl.html#af89e8b4413c870557c97cf9c8a3fe1e9',1,'gl']]],
+  ['starttime_100',['startTime',['../structUnitTestRunner_1_1TestResult.html#a4a9729ea0d39217a16dd619db024a398',1,'UnitTestRunner::TestResult']]],
+  ['state_101',['state',['../classComponentBuilder.html#af09fdfb8bb0edf0a6c2f19d5d54563f4',1,'ComponentBuilder::state'],['../classAudioProcessorValueTreeState.html#ad7de02052d045956f56018e009dc50c6',1,'AudioProcessorValueTreeState::state'],['../structdsp_1_1ProcessorDuplicator.html#a5907f78806648c78d794e1f16943df9d',1,'dsp::ProcessorDuplicator::state']]],
+  ['statefilechooser_102',['stateFileChooser',['../classStandalonePluginHolder.html#a5f6cf68a9218c9f93837bc13b7841393',1,'StandalonePluginHolder']]],
+  ['states_103',['states',['../namespacegl.html#a1d1dfbaa95ddc71b55b20bca67a16d33',1,'gl']]],
+  ['statestack_104',['stateStack',['../classLowLevelGraphicsPostScriptRenderer.html#a95a55fd1cd7588048a37ac86fa384849',1,'LowLevelGraphicsPostScriptRenderer']]],
+  ['steelblue_105',['steelblue',['../namespaceColours.html#a588c5015b8beea03960fd220c973e70d',1,'Colours']]],
+  ['stencil_106',['stencil',['../namespacegl.html#a1c2ec637bc0712e4237c1b8c90e02322',1,'gl']]],
+  ['stencilbufferbits_107',['stencilBufferBits',['../classOpenGLPixelFormat.html#aa94f3f667e41465ea29b6f259d9abf8b',1,'OpenGLPixelFormat']]],
+  ['stencilcleartag_108',['stencilClearTag',['../namespacegl.html#a52d45314d431f7d64d9b7b64ef927f4e',1,'gl']]],
+  ['stopatend_109',['stopAtEnd',['../structSlider_1_1RotaryParameters.html#a2e705ed5eb148f3f3eb1e89a72ff634f',1,'Slider::RotaryParameters']]],
+  ['stopkey_110',['stopKey',['../classKeyPress.html#a4ebc694e95335f25418c99eb2235d815',1,'KeyPress']]],
+  ['storageblockbinding_111',['storageBlockBinding',['../namespacegl.html#ae1ba5ea319c913ae64e99bc0079ce5ab',1,'gl']]],
+  ['storageblockindex_112',['storageBlockIndex',['../namespacegl.html#a7f9b76ebc66e5542f5d192f0f01ec93c',1,'gl']]],
+  ['storageformat_113',['storageFormat',['../structPropertiesFile_1_1Options.html#aed68b3ff89a6943aeac93af26effec2d',1,'PropertiesFile::Options']]],
+  ['storagesamples_114',['storageSamples',['../namespacegl.html#a07bcb6b2ce71d0852a757daf63b263e6',1,'gl']]],
+  ['storagetype_115',['storagetype',['../namespacegl.html#a8938ecd8908fc581f46f9e6fd2079d2a',1,'gl']]],
+  ['stream_116',['stream',['../namespacegl.html#a3a0f500782e4461d09f1e29189835b3d',1,'gl']]],
+  ['stride_117',['stride',['../namespacegl.html#a5f655ae61ce43b078cbff7cfe363d568',1,'gl']]],
+  ['strides_118',['strides',['../namespacegl.html#ab3fb3e346bf30cc218822c55a0eb74c5',1,'gl']]],
+  ['string_119',['string',['../classOSCTypes.html#ad427b15ae32b26b2e0c28f0932eed263',1,'OSCTypes::string'],['../namespacegl.html#ad7acdf57d94829f964ff1dc581fc4705',1,'gl::string']]],
+  ['stringlen_120',['stringlen',['../namespacegl.html#acde29865e531b4849f88ed20c6dcf0a7',1,'gl']]],
+  ['stringrange_121',['stringRange',['../classTextLayout_1_1Line.html#a2980388305522b3a4595196e7bbf09a2',1,'TextLayout::Line::stringRange'],['../classTextLayout_1_1Run.html#a5e78255b382519784f9950efeae14f57',1,'TextLayout::Run::stringRange']]],
+  ['strings_122',['strings',['../classStringArray.html#ac10f010a31e1dcd6220d278a1603e37a',1,'StringArray::strings'],['../namespacegl.html#a8639a2c90be16742b8efb795d7c7a4ed',1,'gl::strings']]],
+  ['strokepath_123',['strokePath',['../classDrawableShape.html#a9400e1628d38b4719c211da4158bc2ff',1,'DrawableShape']]],
+  ['stroketype_124',['strokeType',['../classDrawableShape.html#af636e2ff4b818d2b51994291facb30f6',1,'DrawableShape']]],
+  ['style_125',['style',['../classTypeface.html#a4169174330e29936cda2170a51a36df8',1,'Typeface::style'],['../classComponentPeer.html#aa96d0558fabd66eea5baeded157a873d',1,'ComponentPeer::style'],['../structPushNotifications_1_1Notification_1_1Action.html#a3ae288a9d4a6c29d907430ee38229166',1,'PushNotifications::Notification::Action::style']]],
+  ['styleflags_126',['styleFlags',['../classComponentPeer.html#a8322b7cdb134bc52f443cd587ffc3f75',1,'ComponentPeer']]],
+  ['subcategoryname_127',['subcategoryName',['../structUnitTestRunner_1_1TestResult.html#af0a632786980a63693a86bb9942959c0',1,'UnitTestRunner::TestResult']]],
+  ['subfolders_128',['subFolders',['../structKnownPluginList_1_1PluginTree.html#a46a202981e3ec6943e51ddbe2866a8d0',1,'KnownPluginList::PluginTree']]],
+  ['submenu_129',['subMenu',['../structPopupMenu_1_1Item.html#ac3da3a6179a8ddb32c3f8de05a4f91e1',1,'PopupMenu::Item']]],
+  ['subpathindex_130',['subPathIndex',['../classPathFlatteningIterator.html#a96ac386608cfe18dde7de5a433aac417',1,'PathFlatteningIterator']]],
+  ['subtitle_131',['subtitle',['../structPushNotifications_1_1Notification.html#a187733b87ad3bba14b690f021ac4ee0a',1,'PushNotifications::Notification']]],
+  ['succeeded_132',['succeeded',['../structOnlineUnlockStatus_1_1UnlockResult.html#a05958e80831364da7c4a2bead72fad6a',1,'OnlineUnlockStatus::UnlockResult']]],
+  ['suggestedcolour_133',['suggestedColour',['../structAudioProcessorEditor_1_1ParameterControlHighlightInfo.html#ae06159d036b60b93709ac4a5553af0ba',1,'AudioProcessorEditor::ParameterControlHighlightInfo']]],
+  ['sumoutput_134',['sumOutput',['../namespacegl.html#a5d14e91166b44ea9f8ebb94bd6c1a37b',1,'gl']]],
+  ['surfaces_135',['surfaces',['../namespacegl.html#a8c2d49638382f782b88bad56c901ccc7',1,'gl']]],
+  ['sustain_136',['sustain',['../structADSR_1_1Parameters.html#a3722c4a821ccb7affd869fb257729aa8',1,'ADSR::Parameters']]],
+  ['swizzle_137',['swizzle',['../namespacegl.html#a0f0f61c545262318ed8612d9b0186c8e',1,'gl']]],
+  ['swizzlew_138',['swizzlew',['../namespacegl.html#aaf72861e2d272a042d6645b0295c9cba',1,'gl']]],
+  ['swizzlex_139',['swizzlex',['../namespacegl.html#ab07ede14e70de55b831e8066e1d6c119',1,'gl']]],
+  ['swizzley_140',['swizzley',['../namespacegl.html#aaf990616a9884a909b1dc64f9011ec3e',1,'gl']]],
+  ['swizzlez_141',['swizzlez',['../namespacegl.html#a1c3cb1caa0d412fca8ecf375d5cf8351',1,'gl']]],
+  ['symbolname_142',['symbolName',['../structExpression_1_1Symbol.html#a8ea461b91478b99e10a04956c38f5d68',1,'Expression::Symbol']]],
+  ['symmetricskew_143',['symmetricSkew',['../classNormalisableRange.html#a3a588ad45b07463d74aca98d0589845d',1,'NormalisableRange']]]
 ];
